@@ -17,7 +17,8 @@ class CameraBehavior extends Behavior {
     @SuppressWarnings("unchecked")
     public void processStimulus(Enumeration criteria) {
         //WakeupOnElapsedTime w = new WakeupOnElapsedTime(100);
-        WakeupOnBehaviorPost w = new WakeupOnBehaviorPost(null,1);
+        //WakeupOnBehaviorPost w = new WakeupOnBehaviorPost(null,1);
+        WakeupOnBehaviorPost w = new WakeupOnBehaviorPost(virtualUniverse.timerBehavior,1);
         wakeupOn(w);
         double ratio= 1.0-Math.pow(interpolateRatio,((double)virtualUniverse.elapsedTime)/1000.0);
         virtualUniverse.scene.cameraNowS = virtualUniverse.scene.cameraNowS + ratio*(virtualUniverse.scene.cameraNextS - virtualUniverse.scene.cameraNowS);
