@@ -5,6 +5,7 @@ import java.util.*;
 import javax.media.j3d.*;
 import javax.vecmath.*;
 import com.bulletphysics.collision.shapes.*;
+import com.bulletphysics.extras.gimpact.GImpactMeshShape;
 import com.sun.j3d.loaders.Scene;
 import com.bulletphysics.util.ObjectArrayList;
 import static java.lang.Math.*;
@@ -468,11 +469,28 @@ public class Util {
   //左右軸まわりの回転：ピッチ(pitch)
   //前後軸まわりの回転：ロール(roll)
 
+    /**
+     * デグリーのオイラー角からラジアンのオイラー角への変換。
+     */
+    public static Vector3d rev2rot(Vector3d rev) {
+        Vector3d ret = new Vector3d(rev);
+        ret.scale(Math.PI/180.0);
+        return ret;
+    }
+
+    /**
+     * ラジアンのオイラー角からデグリーのオイラー角への変換。
+     */
+    public static Vector3d rot2rev(Vector3d rot) {
+        Vector3d ret = new Vector3d(rot);
+        ret.scale(180.0/Math.PI);
+        return ret;
+    }
 //================================================================================
 
     /**
      * 引数として与えられたjavax.media.j3d.Nodeの形状に対応する
-     * import com.bulletphysics.collision.shapes.ConvexHullShapeを
+     * com.bulletphysics.collision.shapes.ConvexHullShapeを
      * 生成します．
      */
     static public ConvexHullShape makeConvexHullShape(Node n) {
@@ -490,6 +508,17 @@ public class Util {
         ConvexHullShape chs2 = new ConvexHullShape(vertexes2);
         return chs2;
     }
+    /**
+     * 引数として与えられたjavax.media.j3d.Nodeに含まれる点の集合を
+     * com.bulletphysics.util.ObjectArrayList<Vector3f>で返します。
+     */
+    public static ObjectArrayList<Vector3f> listingVertexes(Node n) {
+        ObjectArrayList<Vector3f> vertexes1 = new ObjectArrayList<Vector3f>();
+        Transform3D t0 = new Transform3D();
+        t0.setIdentity();
+        listingVertexes(n,vertexes1,t0);
+        return vertexes1;
+    }
     static void listingVertexes(Node n,ObjectArrayList<Vector3f> vertexes,Transform3D t0) {
         if (n instanceof Shape3D) {
             Shape3D s = (Shape3D)n;
@@ -550,12 +579,7 @@ public class Util {
     }
 //================================================================================
 
-    /**
-     * 引数として与えられたjavax.media.j3d.Nodeの形状に対応する
-     * import com.bulletphysics.collision.shapes.BvhTriangleMeshShapeを
-     * 生成します．
-     */
-    public static BvhTriangleMeshShape makeBvhTriangleMeshShape(Node n) {
+    static TriangleIndexVertexArray makeTriangleIndexVertexArray(Node n) {
         int vertStride = 4 * 3 /* sizeof(btVector3) */;
         int indexStride = 3 * 4 /* 3*sizeof(int) */;
 
@@ -578,11 +602,35 @@ System.out.println("totalTriangles:"+totalTriangles);
                 indexStride,
                 totalVerts, vertices, vertStride);
 
+        return indexVertexArrays;
+    }
+
+    /**
+     * 引数として与えられたjavax.media.j3d.Nodeの形状に対応する
+     * com.bulletphysics.collision.shapes.BvhTriangleMeshShapeを
+     * 生成します．
+     */
+    public static BvhTriangleMeshShape makeBvhTriangleMeshShape(Node n) {
+        TriangleIndexVertexArray indexVertexArrays = makeTriangleIndexVertexArray(n);
+
         boolean useQuantizedAabbCompression = true;
         BvhTriangleMeshShape shape = new BvhTriangleMeshShape(indexVertexArrays, useQuantizedAabbCompression);
         return shape;
     }
 
+    /**
+     * 引数として与えられたjavax.media.j3d.Nodeの形状に対応する
+     * com.bulletphysics.extras.gimpact.GImpactMeshShapeを
+     * 生成します．
+     */
+    public static GImpactMeshShape makeGImpactMeshShape(Node n) {
+        TriangleIndexVertexArray indexVertexArrays = makeTriangleIndexVertexArray(n);
+
+        GImpactMeshShape shape = new GImpactMeshShape(indexVertexArrays);
+        shape.updateBound();
+        return shape;
+    }
+
     static int[] countVertsAndTriangles(Node n) {
         int verCount=0;
         int triCount=0;
